##  Searching, Filtering, and Sorting
Search, filter, and sort functions help you streamline navigation, save time, and ensure better control over large sets of reports.
  * Search: Quickly find a specific report using keywords.
  * Filter: Narrow down reports to your required subset based on criteria like ownership, permissions, creation date, modification date, and type of reports.
  * Sort: Organize reports by attributes such as name, date, or relevance to find what you need faster.


![Searching, Filtering, and Sorting Reports](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743dbb57a441014b064b2d128e82c96_LowRes.gif)
Searching, Filtering, and Sorting Reports
